Quick Start
==============

This quick start is intended to get you setup with Yellowbrick in development
mode (since the project is still under development).

1. Fork and clone the repository. After clicking fork in the upper right corner
for your own copy of yellowbrick to your github account. Clone it in a directory
of your choice.::

        $ git clone https://github.com/[YOURUSERNAME]/yellowbrick
        $ cd yellowbrick

2. Create virtualenv and create the dependencies::

        $ virtualenv venv
        $ pip install -r requirements.txt

3. Fetch and switch to development.::

        $ git fetch
        $ git checkout develop
